.. toctree::
   :maxdepth: 2

Development tools API
~~~~~~~~~~~~~~~~~~~~~

Test phmdoctest from within a python script
===========================================

.. module:: phmdoctest.simulator

.. autofunction:: run_and_pytest

.. module:: phmdoctest.tool

Read Markdown fenced code blocks
================================

.. autofunction:: fenced_code_blocks

.. autofunction:: fenced_block_nodes
